@@ -9,7 +9,7 @@ require Exporter;
 @EXPORT = qw(dd ddx);
 @EXPORT_OK = qw(dump pp dumpf quote);
 
-$VERSION = "1.22";
+$VERSION = "1.24";
 $DEBUG = 0;
 
 use overload ();
@@ -229,6 +229,9 @@ sub _dump
 	    if (!defined $$rval) {
 		$out = "undef";
 	    }
+	    elsif ($$rval =~ /^-?(?:nan|inf)/i) {
+		$out = str($$rval);
+	    }
 	    elsif (do {no warnings 'numeric'; $$rval + 0 eq $$rval}) {
 		$out = $$rval;
 	    }
@@ -358,7 +361,7 @@ sub _dump
 	    my $vpad = $INDENT . (" " x ($klen_pad ? $klen_pad + 4 : 0));
 	    $val =~ s/\n/\n$vpad/gm;
 	    my $kpad = $nl ? $INDENT : " ";
-	    $key .= " " x ($klen_pad - length($key)) if $nl;
+	    $key .= " " x ($klen_pad - length($key)) if $nl && $klen_pad > length($key);
 	    $out .= "$kpad$key => $val,$nl";
 	}
 	$out =~ s/,$/ / unless $nl;
@@ -481,7 +484,7 @@ sub str {
       for ($_[0]) {
       # Check for repeated string
       if (/^(.)\1\1\1/s) {
-          # seems to be a repating sequence, let's check if it really is
+          # seems to be a repeating sequence, let's check if it really is
           # without backtracking
           unless (/[^\Q$1\E]/) {
               my $base = quote($1);
@@ -569,10 +572,9 @@ Data::Dump - Pretty printing of data structures
 
 =head1 DESCRIPTION
 
-This module provide a few functions that traverse their
-argument and produces a string as its result.  The string contains
-Perl code that, when C<eval>ed, produces a deep copy of the original
-arguments.
+This module provides a few functions that traverse their
+argument list and return a string containing Perl code that,
+when C<eval>ed, produces a deep copy of the original arguments.
 
 The main feature of the module is that it strives to produce output
 that is easy to read.  Example:
@@ -714,6 +716,8 @@ on C<Data::Dumper> by Gurusamy Sarathy <gsar@umich.edu>.
  Copyright 1998-2010 Gisle Aas.
  Copyright 1996-1998 Gurusamy Sarathy.
 
+This distribution is currenly maintained by Breno G. de Oliveira.
+
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
